containertools.get_first_element_starting_before_or_at_offset
=============================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_before_or_at_offset.get_first_element_starting_before_or_at_offset
   :noindex:
